@@ -4,6 +4,6 @@ License: GPLv3
 """
 
 
-__version__ = '2.1.0'
+__version__ = '2.1.1'
 
-from .crawlio import Crawler
+from .crawlio import Crawler, Selector
